sensAI - the Python library for sensible AI
===========================================

.. toctree::
   :caption: Guides and Tutorials
   :glob:

   *


.. toctree::
   :caption: Modules

   sensai/index



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
